Readme
======
## Project description

### What is it ?

**ipoly** is a Python package that provides features that Data Scientist may need that aims to simplify the development thanks to functions using polymorphic inputs.

### Main features

Here are just a few of the things that **ipoly** can do :

- Send emails easily
- Load most types of file with a unique function looking recursively for the file
- Save most types of file with a unique function
- Update a DataFrame with new data easily
- Generate a .tex or .pdf easily using only Python
- Prepare automatically a DataFrame for ML (filling missing data, dropping too much correlated features ...)

## Where to get it

The source code is currently hosted on GitHub at: https://github.com/Danguilhen/ipoly

```
pip install ipoly
```

## Contributing to ipoly Open Source Helpers

All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome.
